GenAI.Provider.Groq.Encoder
(Noizu Labs, GenAI Wrapper v0.3.0)
Summary
Functions
Callback implementation for GenAI.Model.EncoderBehaviour.completion_response/6.
Callback implementation for GenAI.Model.EncoderBehaviour.default_hyper_params/5.
Format message for provider/model type.
Format tool for provider/model type.
Prepare endpoint and method to make inference call to
Prepare endpoint and method to make inference call to
Prepare request headers
Obtain list of hyper params supported by given model including mapping and conditional rules/alterations
Callback implementation for GenAI.Model.EncoderBehaviour.normalize_messages/5.
Prepare request body to be passed to inference call.
Set setting with dynamic model based logic.
Callback implementation for GenAI.Model.EncoderBehaviour.with_dynamic_setting/5.
Set setting as_setting with dynamic model based logic.
Functions
Callback implementation for GenAI.Model.EncoderBehaviour.completion_response/6.
Callback implementation for GenAI.Model.EncoderBehaviour.default_hyper_params/5.
Format message for provider/model type.
Format tool for provider/model type.
Prepare endpoint and method to make inference call to
Prepare endpoint and method to make inference call to
Prepare request headers
Obtain list of hyper params supported by given model including mapping and conditional rules/alterations
Callback implementation for GenAI.Model.EncoderBehaviour.normalize_messages/5.
Prepare request body to be passed to inference call.
Set setting with dynamic model based logic.
Callback implementation for GenAI.Model.EncoderBehaviour.with_dynamic_setting/5.
Set setting as_setting with dynamic model based logic.
Callback implementation for GenAI.Model.EncoderBehaviour.with_dynamic_setting_as/6.